Skip to contents

Create a gyro vector

Usage

gyro(
  bursts = list(),
  frequency = units::set_units(double(), "Hz"),
  start = NULL
)

Arguments

bursts

a list of matrices

frequency

The frequency of the gyroscope recordings. Either the same length of bursts or it will be recycled. If no units are specified, the frequency is assumed to be in Hz.

start

Start time of the burst, in POSIXct format