Skip to contents

Return the row indices of a move2 object where more than one column set for a given sensor contains data. Functions that extract IMU data will error if a single timestamp contains multiple sources of IMU data for the same sensor.

To resolve duplicated rows, pass a specific set of IMU columns to the colset argument of as_*() or remove the duplicated data.

  • duplicated_acc_rows() — checks acceleration column sets used by as_acc().

  • duplicated_mag_rows() — checks magnetometer column sets used by as_mag().

  • duplicated_gyro_rows() — checks gyroscope column sets used by as_gyro().

Usage

duplicated_acc_rows(x, colsets = NULL)

duplicated_mag_rows(x, colsets = NULL)

duplicated_gyro_rows(x, colsets = NULL)

Arguments

x

A move2 object.

colsets

List of imu_colset objects to check for overlap. Defaults to the column sets detected by the corresponding active_*_colsets().

Value

An integer vector of row indices with duplicated data across column sets.

See also

active_acc_colsets(), active_mag_colsets(), active_gyro_colsets() to identify available column sets in a move2 object.

as_acc(), as_mag(), as_gyro() to extract IMU data from a move2 object.