Return the row indices of a move2 object where more than one column set
for a given sensor contains data. Functions that extract IMU data
will error if a single timestamp contains multiple sources of IMU data
for the same sensor.
To resolve duplicated rows, pass a specific set of IMU columns to the
colset argument of as_*() or remove the duplicated data.
Usage
duplicated_acc_rows(x, colsets = NULL)
duplicated_mag_rows(x, colsets = NULL)
duplicated_gyro_rows(x, colsets = NULL)See also
active_acc_colsets(), active_mag_colsets(),
active_gyro_colsets() to identify available column sets in a move2
object.
as_acc(), as_mag(), as_gyro() to extract IMU data from a
move2 object.